==> struts-6.7.0-all.zip: struts-6.7.0/src/core/src/main/java/org/apache/struts2/dispatcher/listener/ListenerHostConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.dispatcher.listener;

import org.apache.struts2.dispatcher.HostConfig;

import javax.servlet.ServletContext;
import java.util.Iterator;
import java.util.Collections;

/**
 * Host configuration that just holds a ServletContext
 */
public class ListenerHostConfig implements HostConfig {
    private ServletContext servletContext;

    public ListenerHostConfig(ServletContext servletContext) {
        this.servletContext = servletContext;
    }

    public String getInitParameter(String key) {
        return null;
    }

    public Iterator<String> getInitParameterNames() {
        return Collections.<String>emptyList().iterator();
    }

    public ServletContext getServletContext() {
        return servletContext;  
    }
}

==> struts-7.0.0-all.zip: struts-7.0.0/src/core/src/main/java/org/apache/struts2/dispatcher/listener/ListenerHostConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.dispatcher.listener;

import org.apache.struts2.dispatcher.HostConfig;

import jakarta.servlet.ServletContext;
import java.util.Iterator;
import java.util.Collections;

/**
 * Host configuration that just holds a ServletContext
 */
public class ListenerHostConfig implements HostConfig {
    private final ServletContext servletContext;

    public ListenerHostConfig(ServletContext servletContext) {
        this.servletContext = servletContext;
    }

    @Override
    public String getInitParameter(String key) {
        return null;
    }

    @Override
    public Iterator<String> getInitParameterNames() {
        return Collections.emptyIterator();
    }

    @Override
    public ServletContext getServletContext() {
        return servletContext;
    }
}
